@@ -7,7 +7,12 @@ Module to manage IAM policies to grant access to ECS Services to DynamodbTables
 """
 
 from ecs_composex.dynamodb.dynamodb_aws import lookup_dynamodb_config
-from ecs_composex.dynamodb.dynamodb_params import TABLE_ARN, TABLE_NAME
+from ecs_composex.dynamodb.dynamodb_params import (
+    MAPPINGS_KEY,
+    RES_KEY,
+    TABLE_ARN,
+    TABLE_NAME,
+)
 from ecs_composex.resource_settings import (
     handle_lookup_resource,
     handle_resource_to_services,
@@ -33,16 +38,14 @@ def dynamodb_to_ecs(resources, services_stack, res_root_stack, settings):
     Function to apply SQS settings to ECS Services
     :return:
     """
-    resources_mappings = {}
     new_resources = [
-        resources[res_name] for res_name in resources if not resources[res_name].lookup
-    ]
-    lookup_resources = [
         resources[res_name]
         for res_name in resources
-        if resources[res_name].lookup and not resources[res_name].properties
+        if resources[res_name].cfn_resource
+    ]
+    lookup_resources = [
+        resources[res_name] for res_name in resources if resources[res_name].mappings
     ]
-    create_dyndb_mappings(resources_mappings, lookup_resources, settings)
     for new_res in new_resources:
         handle_resource_to_services(
             new_res,
@@ -55,5 +58,5 @@ def dynamodb_to_ecs(resources, services_stack, res_root_stack, settings):
         )
     for resource in lookup_resources:
         handle_lookup_resource(
-            resources_mappings, "dynamodb", resource, TABLE_ARN, [TABLE_NAME]
+            settings.mappings[RES_KEY], MAPPINGS_KEY, resource, TABLE_ARN, [TABLE_NAME]
         )
