@@ -43,14 +43,36 @@ def get_default_cluster_config():
     )
 
 
+def evaluate_fargate_is_set(providers, cluster_def):
+    """
+    Evaluate if FARGATE or FARGATE_SPOT is defined in the cluster
+
+    :param list[str] providers:
+    :param dict cluster_def:
+    :return: Whether FARGATE or FARGATE_SPOT is available
+    :rtype: bool
+    """
+
+    fargate_present = FARGATE_PROVIDER in providers
+    fargate_spot_present = FARGATE_SPOT_PROVIDER in providers
+    if not fargate_present and not fargate_spot_present:
+        LOG.warning(
+            f"{cluster_def['clusterName']} - "
+            f"No {FARGATE_PROVIDER} nor {FARGATE_SPOT_PROVIDER} listed in Capacity Providers."
+            "Overriding to EC2 Launch Type"
+        )
+        return "EC2"
+    return None
+
+
 def evaluate_capacity_providers(cluster_def):
     """
     When using Looked'Up cluster, if there is no Fargate Capacity Provider, defined on cluster,
     rollback to EC2 mode.
 
     :param dict cluster_def:
-    :return: The override Capacity Provider
-    :rtype: str|None
+    :return: List of capacity providers set on the ECS Cluster.
+    :rtype: list
     """
     providers = []
     providers_strategies = []
@@ -62,20 +84,28 @@ def evaluate_capacity_providers(cluster_def):
             for provider in cluster_def["defaultCapacityProviderStrategy"]
         ]
     if not providers and not providers_strategies:
-        return "EC2"
-    if providers and providers_strategies:
+        LOG.warning(
+            f"{cluster_def['clusterName']} - No capacityProvider nor defaultCapacityProviderStrategy defined."
+            "Overriding to EC2"
+        )
+    elif providers and providers_strategies:
         for name in providers_strategies:
             if name not in providers:
                 providers.append(name)
-        if "FARGATE" not in providers or "FARGATE_SPOT" in providers:
-            return "EC2"
-    fargate_present = "FARGATE" in providers or "FARGATE" in providers_strategies
-    fargate_spot_present = (
-        "FARGATE_SPOT" in providers or "FARGATE_SPOT" in providers_strategies
+    return providers
+
+
+def define_cluster_lookup_props(cluster_r, settings):
+    cluster_mapping = {}
+    if not cluster_r:
+        return cluster_mapping
+
+    cluster_mapping = {CLUSTER_NAME.title: {"Name": cluster_r["clusterName"]}}
+    settings.ecs_cluster_providers = evaluate_capacity_providers(cluster_r)
+    settings.ecs_cluster_platform_override = evaluate_fargate_is_set(
+        settings.ecs_cluster_providers, cluster_r
     )
-    if not fargate_present and not fargate_spot_present:
-        return "EC2"
-    return None
+    return cluster_mapping
 
 
 def lookup_ecs_cluster(session, cluster_lookup):
@@ -105,8 +135,7 @@ def lookup_ecs_cluster(session, cluster_lookup):
             LOG.info(
                 f"Found ECS Cluster {cluster_lookup}. Setting {CLUSTER_NAME.title} accordingly."
             )
-            override = evaluate_capacity_providers(cluster_r["clusters"][0])
-            return cluster_r["clusters"][0]["clusterName"], override
+            return cluster_r["clusters"][0]
     except ClientError as error:
         LOG.error(error)
         raise
@@ -125,6 +154,13 @@ def define_cluster(cluster_def):
     props["Metadata"] = metadata
     if not keyisset("ClusterName", props):
         props["ClusterName"] = Ref(AWS_STACK_NAME)
+    if keyisset("DefaultCapacityProviderStrategy", props) and not keyisset(
+        "CapacityProviders", props
+    ):
+        raise KeyError(
+            "When specifying DefaultCapacityProviderStrategy"
+            " you must specify CapacityProviders"
+        )
     cluster = Cluster(CLUSTER_T, **props)
     return cluster
 
@@ -141,7 +177,7 @@ def import_from_x_aws_cluster(compose_content):
         return
     if compose_content[x_aws_key].startswith("arn:aws"):
         cluster_name = re.sub(
-            pattern=r"(arn:aws:ecs:[\S]+:[0-9]{12}:cluster/)",
+            pattern=r"(arn:aws(?:-[a-z]+)?:ecs:[\S]+:[0-9]{12}:cluster/)",
             repl="",
             string=compose_content[x_aws_key],
         )
@@ -150,15 +186,19 @@ def import_from_x_aws_cluster(compose_content):
     compose_content[RES_KEY] = {"Use": cluster_name}
 
 
-def define_cluster_lookup_props(cluster_r, settings):
-    cluster_mapping = {}
-    if not cluster_r:
-        return cluster_mapping
-    if cluster_r[0]:
-        cluster_mapping = {CLUSTER_NAME.title: {"Name": cluster_r[0]}}
-    if cluster_r[1] is not None:
-        settings.ecs_cluster_platform_override = cluster_r[1]
-    return cluster_mapping
+def new_cluster_settings_config(cluster_identifier, settings):
+    """
+    When creating a new cluster, define additional ComposeXSettings values.
+
+    :param troposphere.ecs.Cluster cluster_identifier:
+    :param ecs_composex.common.settings.ComposeXSettings settings:
+    """
+    settings.ecs_cluster = Ref(cluster_identifier)
+    settings.ecs_cluster_providers = (
+        cluster_identifier.CapacityProviders
+        if hasattr(cluster_identifier, "CapacityProviders")
+        else []
+    )
 
 
 def add_ecs_cluster(root_stack, settings):
@@ -167,7 +207,6 @@ def add_ecs_cluster(root_stack, settings):
 
     :param ecs_composex.common.stacks.ComposeXStack root_stack:
     :param ecs_composex.common.settings.ComposeXSettings settings:
-    :return: cluster identifier
     """
     cluster_identifier = Ref(AWS_STACK_NAME)
     cluster_mapping = {}
@@ -176,8 +215,9 @@ def add_ecs_cluster(root_stack, settings):
         LOG.info("x-aws-cluster was set. Overriding any defined x-cluster settings")
     if not keyisset(RES_KEY, settings.compose_content):
         LOG.info("No cluster information provided. Creating a new one")
-        root_stack.stack_template.add_resource(get_default_cluster_config())
-        cluster_identifier = Ref(CLUSTER_T)
+        cluster_identifier = root_stack.stack_template.add_resource(
+            get_default_cluster_config()
+        )
     elif isinstance(settings.compose_content[RES_KEY], dict):
         if keyisset("Use", settings.compose_content[RES_KEY]):
             LOG.info(f"Using cluster {settings.compose_content[RES_KEY]['Use']}")
@@ -186,14 +226,18 @@ def add_ecs_cluster(root_stack, settings):
             }
         elif keyisset("Lookup", settings.compose_content[RES_KEY]):
             cluster_r = lookup_ecs_cluster(
-                settings.session, settings.compose_content[RES_KEY]["Lookup"]
+                settings.session,
+                settings.compose_content[RES_KEY]["Lookup"],
             )
             cluster_mapping = define_cluster_lookup_props(cluster_r, settings)
         elif keyisset("Properties", settings.compose_content[RES_KEY]):
-            cluster = define_cluster(settings.compose_content[RES_KEY])
-            root_stack.stack_template.add_resource(cluster)
-            return Ref(cluster)
+            cluster_identifier = define_cluster(settings.compose_content[RES_KEY])
+            root_stack.stack_template.add_resource(cluster_identifier)
     if cluster_mapping:
         root_stack.stack_template.add_mapping("Ecs", cluster_mapping)
         cluster_identifier = FindInMap("Ecs", CLUSTER_NAME.title, "Name")
-    return cluster_identifier
+
+    if isinstance(cluster_identifier, Cluster):
+        new_cluster_settings_config(cluster_identifier, settings)
+    else:
+        settings.ecs_cluster = cluster_identifier
