@@ -33,7 +33,7 @@ LAUNCH_TYPE_T = "EcsLaunchType"
 LAUNCH_TYPE = Parameter(
     LAUNCH_TYPE_T,
     Type="String",
-    AllowedValues=["EC2", "FARGATE", "EXTERNAL"],
+    AllowedValues=["EC2", "FARGATE", "EXTERNAL", "CAPACITY_PROVIDERS"],
     Default="FARGATE",
 )
 
